program_rlimit_tuning

package module
v0.0.0-...-23a357e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2023 License: Apache-2.0 Imports: 2 Imported by: 0

README

program-rlimit-tuning

Under Linux system, the number of files that a process can open is 1024 by default.
If the process needs high performance, we need to change the file open limit.

Install

Run the following command under your project:

go get -u github.com/vvfly/base/program-rlimit-tuning

Usage

Just import it directly, such as:

package main

import (
	_ "github.com/vvfly/base/program-rlimit-tuning"
	"log"
)

func main() {
	log.Println("server is running")
}

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Tuning

func Tuning() error

Types

This section is empty.

Directories

Path Synopsis

Jump to